@@ -2,7 +2,7 @@
 
 
 #
-#  surveydata/R/cleandata.R by Andrie de Vries  Copyright (C) 2011-2012
+#  surveydata/R/cleandata.R by Andrie de Vries  Copyright (C) 2011-2017
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -19,6 +19,10 @@
 #
 
 
+
+# don't know --------------------------------------------------------------
+
+
 #' Tests whether levels contain "Don't know".
 #' 
 #' Returns TRUE if x contains any instances of dk  
@@ -29,22 +33,23 @@
 #' @export 
 #' @family Functions to clean data
 #' @keywords "clean data"
-hasDK <- function(x, dk = "Don't Know"){
+has_dont_know <- function(x, dk = "Don't Know"){
   l <- if(is.factor(x)) levels(x) else unique(x)
   any(l %in% dk)
 }
 
+
 #' Removes "Don't know" from levels and replaces with NA.
 #' 
 #' Tests the levels of x contain any instances of "Don't know".  If so, replaces these levels with `NA`
 #' 
-#' @inherit hasDK
+#' @inherit has_dont_know
 #' @return A factor with "Dont know" removed
 #' @export 
 #' @family Functions to clean data
 #' @keywords "clean data"
-removeDK <- function(x, dk = "Don't Know"){
-  if (hasDK(x, dk)){
+remove_dont_know <- function(x, dk = "Don't Know"){
+  if (has_dont_know(x, dk)){
     if(is.factor(x)){
       l <- levels(x)
       l[which(levels(x) %in% dk)] <- NA
@@ -57,39 +62,51 @@ removeDK <- function(x, dk = "Don't Know"){
   x
 }
 
+
+
 #' Removes "Do not know" and other similar words from factor levels in data frame.
 #' 
 #' Removes "Do not know" and other similar words from factor levels in data frame
 #' 
 #' @param x List or data frame 
 #' @param dk Character vector, containing search terms, e.g. `c("Do not know", "DK")`.  These terms will be replaced by `NA`. If `NULL`, defaults to `c("I don't know", "Don't Know", "Don't know", "Dont know" , "DK")`
+#' @param message If TRUE, displays message with the number of instances that were removed.
+#' 
 #' @seealso [hasDK()] and [removeDK()]
 #' @return A data frame
 #' @export
 #' @family Functions to clean data
 #' @keywords "clean data"
-removeAllDK <- function(x, dk=NULL){
+remove_all_dont_know <- function(x, dk=NULL, message=TRUE){
   if (is.null(dk)){
     dk <- c("I don't know", "Don't Know", "Don't know", "Dont know" , "DK")		
   }
-  newx <- lapply(x, removeDK, dk)
-  n1 <- sum(as.numeric(lapply(x, hasDK, dk)))
-  n2 <- sum(as.numeric(lapply(newx, hasDK, dk)))
+  newx <- lapply(x, remove_dont_know, dk)
+  n1 <- sum(as.numeric(lapply(x, has_dont_know, dk)))
+  n2 <- sum(as.numeric(lapply(newx, has_dont_know, dk)))
   dk <- paste(dk, collapse=", ")
-  message(paste("Removed", n1-n2,"instances of levels that equal [", dk, "]"))
+  if(message){
+    message(paste("Removed", n1-n2,"instances of levels that equal [", dk, "]"))
+  }
   ret <- quickdf(newx)
   attributes(ret) <- attributes(x)
   class(ret) <- class(x)
   ret
 }	
 
+
+
+# leveltest ---------------------------------------------------------------
+
+
 #' Fix level formatting of all question with Yes/No type answers.
 #' 
-#' @param x Surveyor data object
+#' @param x surveydata object
 #' @export
 #' @family Functions to clean data
 #' @keywords "clean data"
-leveltestSPSS <- function(x){
+#' @name leveltest
+leveltest_spss <- function(x){
   ret <- FALSE
   if(inherits(x, "numeric")){
     if(!is.null(attributes(x)$value.labels)){
@@ -99,15 +116,34 @@ leveltestSPSS <- function(x){
   ret
 }
 
+
+#' @export
+#' @rdname leveltest
+leveltest_r <- function(x){
+  ret <- FALSE
+  if(inherits(x, "factor")){
+    if(length(levels(x)) == 2){
+      if(all(levels(x) == c("Yes", "Not selected"))){
+        ret <- TRUE
+      }}}
+  ret
+}
+
+
+
+# fix levels --------------------------------------------------------------
+
+
 #' Fix level formatting of all question with Yes/No type answers.
 #' 
-#' @param dat Surveyor data object
+#' @param dat surveydata object
 #' @export
 #' @family Functions to clean data
 #' @keywords "clean data"
-fixLevels01SPSS <- function(dat){
+#' @rdname fix_levels_01
+fix_levels_01_spss <- function(dat){
   ret <- lapply(dat, function(x){
-    if(leveltestSPSS(x)){
+    if(leveltest_spss(x)){
       x <- factor(x)
       levels(x) <- c("No", "Yes")
       x
@@ -121,32 +157,13 @@ fixLevels01SPSS <- function(dat){
   ret
 }
 
-#' Fix level formatting of all question with Yes/No type answers.
-#' 
-#' @param x surveydata object
-#' @export
-#' @keywords "clean data"
-#' @family Functions to clean data
-leveltestR <- function(x){
-  ret <- FALSE
-  if(inherits(x, "factor")){
-    if(length(levels(x))==2){
-      if(all(levels(x)==c("Yes", "Not selected"))){
-        ret <- TRUE
-      }}}
-  ret
-}
 
-#' Fix level formatting of all question with Yes/No type answers.
-#' 
-#' @param dat surveydata object
 #' @export
-#' @family Functions to clean data
-#' @keywords "clean data"
-fixLevels01R <- function(dat){
+#' @rdname fix_levels_01
+fix_levels_01_r <- function(dat){
   stopifnot(is.surveydata(dat))
   ret <- lapply(dat, function(x){
-    if(leveltestR(x)){
+    if(leveltest_r(x)){
       levels(x) <- c("Yes", "No")
       x
     } else {
@@ -160,26 +177,28 @@ fixLevels01R <- function(dat){
   as.surveydata(ret)
 }
 
-#' Fix level formatting of all question with Yes/No type answers.
-#' 
-#' @param dat surveydata object
-#' @param origin Either "R" or "SPSS"
+
+
+#' @param origin Either `R` or `SPSS`
 #' @export
-#' @family Functions to clean data
-#' @keywords "clean data"
-fixLevels01 <- function(dat, origin=c("R", "SPSS")){
+fix_levels_01 <- function(dat, origin=c("R", "SPSS")){
   origin <- match.arg(origin)
   switch(origin,
-         "R" = fixLevels01R(dat),
-         "SPSS" = fixLevels01SPSS(dat))
+         "R" = fix_levels_01_r(dat),
+         "SPSS" = fix_levels_01_spss(dat))
 }
 
+
+
+# other -------------------------------------------------------------------
+
+
 #' Changes vector to ordered factor, adding NA levels if applicable.
 #' 
 #' @param x character vector
 #' @export
 #' @family Tools
-qOrder <- function(x){
+question_order <- function(x){
   #factor(x, level=levels(x), labels=levels(x), ordered=TRUE)
   if(any(is.na(x))){
     addNA(ordered(x))
@@ -188,6 +207,7 @@ qOrder <- function(x){
   }
 }
 
+
 #' Applies function only to named elements of a list.
 #' 
 #' This is useful to clean only some columns in a list (or `data.frame` or `surveydata` object). This is a simple wrapper around [lapply()] where only the named elements are changed.
@@ -197,7 +217,7 @@ qOrder <- function(x){
 #' @param ... additional arguments passed to `FUN`
 #' @export 
 #' @family Tools
-lapplyNames <- function(x, names, FUN, ...){
+lapply_names <- function(x, names, FUN, ...){
   oldClass <- class(x)
   index <- match(names, names(x))
   if(any(is.na(index))) {
@@ -209,3 +229,4 @@ lapplyNames <- function(x, names, FUN, ...){
   x
 }
 
+
